Index: content/common/view_messages.h |
diff --git a/content/common/view_messages.h b/content/common/view_messages.h |
index f8be887d89f7482e12b10cf018dcd4d46825da5a..cbfd3231420df5569d0bbfbdad29ce023d015e96 100644 |
--- a/content/common/view_messages.h |
+++ b/content/common/view_messages.h |
@@ -25,6 +25,7 @@ |
#include "third_party/WebKit/Source/WebKit/chromium/public/WebPopupType.h" |
#include "third_party/WebKit/Source/WebKit/chromium/public/WebScreenInfo.h" |
#include "third_party/WebKit/Source/WebKit/chromium/public/WebTextInputType.h" |
+#include "ui/base/range/range.h" |
#include "ui/gfx/rect.h" |
#include "webkit/glue/context_menu.h" |
#include "webkit/glue/password_form.h" |
@@ -1682,8 +1683,9 @@ IPC_MESSAGE_ROUTED2(ViewHostMsg_SetTooltipText, |
WebKit::WebTextDirection /* text direction hint */) |
// Notification that the text selection has changed. |
-IPC_MESSAGE_ROUTED1(ViewHostMsg_SelectionChanged, |
- std::string /* currently selected text */) |
+IPC_MESSAGE_ROUTED2(ViewHostMsg_SelectionChanged, |
+ std::string /* currently selected text */, |
+ ui::Range /* selection range */) |
// Asks the browser to display the file chooser. The result is returned in a |
// ViewHost_RunFileChooserResponse message. |
@@ -1715,6 +1717,11 @@ IPC_MESSAGE_ROUTED2(ViewHostMsg_ImeUpdateTextInputState, |
WebKit::WebTextInputType, /* text_input_type */ |
gfx::Rect /* caret_rect */) |
+ |
+// Message sent when the IME text composition range changes. |
+IPC_MESSAGE_ROUTED1(ViewHostMsg_ImeCompositionRangeChanged, |
+ ui::Range /* composition range */) |
+ |
// Required for cancelling an ongoing input method composition. |
IPC_MESSAGE_ROUTED0(ViewHostMsg_ImeCancelComposition) |